[gnome-settings-daemon] power: Use constant in blank test



commit f1214d843d40c90317613e90d866112537d077d5
Author: Bastien Nocera <hadess hadess net>
Date:   Mon Jan 21 10:18:03 2013 +0100

    power: Use constant in blank test

 plugins/power/test.py |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/plugins/power/test.py b/plugins/power/test.py
index a792c7a..5029905 100755
--- a/plugins/power/test.py
+++ b/plugins/power/test.py
@@ -186,8 +186,8 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.reset_idle_timer()
         self.check_unblank(1)
 
-        # and check for blank after 20 seconds
-        self.check_blank(21)
+        # and check for blank after the blank timeout
+        self.check_blank(gsdpowerconstants.SCREENSAVER_TIMEOUT_BLANK + 1)
 
     def test_sleep_inactive_battery(self):
         '''sleep-inactive-battery-timeout'''



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]